@@ -38,7 +38,7 @@
 %% TODO: Import this from elsewhere after attribute types refactor.
 -type header() :: {string(), string()}.
 
-%% @doc Generates a secure encrypted binary convining all the parameters. The
+%% @doc Generates a secure encrypted binary combining all the parameters. The
 %% expiration time must be a 32-bit integer.
 -spec generate_session_data(
         ExpirationTime :: expiration_time(),
@@ -119,26 +119,7 @@ ensure_binary(B) when is_binary(B) ->
 ensure_binary(L) when is_list(L) ->
     iolist_to_binary(L).
 
--ifdef(crypto_compatibility).
--spec encrypt_data(binary(), binary()) -> binary().
-encrypt_data(Data, Key) ->
-    IV = crypto:strong_rand_bytes(16),
-    Crypt = crypto:aes_cfb_128_encrypt(Key, IV, Data),
-    <<IV/binary, Crypt/binary>>.
-
--spec decrypt_data(binary(), binary()) -> binary().
-decrypt_data(<<IV:16/binary, Crypt/binary>>, Key) ->
-    crypto:aes_cfb_128_decrypt(Key, IV, Crypt).
-
--spec gen_key(iolist(), iolist()) -> binary().
-gen_key(ExpirationTime, ServerKey)->
-    crypto:md5_mac(ServerKey, [ExpirationTime]).
-
--spec gen_hmac(iolist(), binary(), iolist(), binary()) -> binary().
-gen_hmac(ExpirationTime, Data, SessionKey, Key) ->
-    crypto:sha_mac(Key, [ExpirationTime, Data, SessionKey]).
-
--else.
+-ifdef(new_crypto_unavailable).
 -spec encrypt_data(binary(), binary()) -> binary().
 encrypt_data(Data, Key) ->
     IV = crypto:strong_rand_bytes(16),
@@ -150,13 +131,32 @@ decrypt_data(<<IV:16/binary, Crypt/binary>>, Key) ->
     crypto:block_decrypt(aes_cfb128, Key, IV, Crypt).
 
 -spec gen_key(iolist(), iolist()) -> binary().
-gen_key(ExpirationTime, ServerKey)->
+gen_key(ExpirationTime, ServerKey) ->
     crypto:hmac(md5, ServerKey, [ExpirationTime]).
 
 -spec gen_hmac(iolist(), binary(), iolist(), binary()) -> binary().
 gen_hmac(ExpirationTime, Data, SessionKey, Key) ->
     crypto:hmac(sha, Key, [ExpirationTime, Data, SessionKey]).
 
+-else. % new crypto available (OTP 23+)
+-spec encrypt_data(binary(), binary()) -> binary().
+encrypt_data(Data, Key) ->
+    IV = crypto:strong_rand_bytes(16),
+    Crypt = crypto:crypto_one_time(aes_128_cfb128, Key, IV, Data, true),
+    <<IV/binary, Crypt/binary>>.
+
+-spec decrypt_data(binary(), binary()) -> binary().
+decrypt_data(<<IV:16/binary, Crypt/binary>>, Key) ->
+    crypto:crypto_one_time(aes_128_cfb128, Key, IV, Crypt, false).
+
+-spec gen_key(iolist(), iolist()) -> binary().
+gen_key(ExpirationTime, ServerKey) ->
+    crypto:mac(hmac, md5, ServerKey, [ExpirationTime]).
+
+-spec gen_hmac(iolist(), binary(), iolist(), binary()) -> binary().
+gen_hmac(ExpirationTime, Data, SessionKey, Key) ->
+    crypto:mac(hmac, sha, Key, [ExpirationTime, Data, SessionKey]).
+
 -endif.
 
 -ifdef(TEST).
@@ -168,7 +168,7 @@ generate_check_session_cookie_test_() ->
      fun generate_check_session_cookie/1}.
 
 setup_server_key() ->
-    crypto:start(),
+    application:start(crypto),
     ["adfasdfasfs",30000].
 
 generate_check_session_cookie([ServerKey, TS]) ->
