@@ -9,15 +9,10 @@ id(X) ->
        X,
        mochiweb_base64url:decode(
          binary_to_list(mochiweb_base64url:encode(binary_to_list(X))))).
--ifdef(rand_mod_unavailable).
-random_binary(Short,Long) ->
-    << <<(random:uniform(256) - 1)>>
-     || _ <- lists:seq(1, Short + random:uniform(1 + Long - Short) - 1) >>.
--else.
+
 random_binary(Short,Long) ->
     << <<(rand:uniform(256) - 1)>>
      || _ <- lists:seq(1, Short + rand:uniform(1 + Long - Short) - 1) >>.
--endif.
 
 empty_test() ->
     id(<<>>).
